
# SketchLib

This package contains various streaming algorithms that are useful for processing massive scale data. For example, for calculating heavy-hitters in a data stream, implementations of the Misra-Gries and Count-Min algorithms are available. The problems that can be solved using this package include F0 and F2 estimation as well as set-membership inquiries (Bloom Filter).  

